# -*- coding: utf-8 -*-

from django.db import models
from django.core.exceptions import ValidationError

from .timetable import Category


class EdtAdeGroup(models.Model):
    ecole = models.ForeignKey("portailuser.Ecole", on_delete=models.CASCADE)
    gid = models.IntegerField(null=True)
    name = models.CharField(max_length=255)

    class Meta:
        ordering = ["gid"]
        unique_together = (("ecole", "name"),)

    def __str__(self):
        return f"Group {self.gid} for {self.ecole}: {self.name}"


def is_hour(value):
    if value < 0 or value > 23:
        raise ValidationError(f"{value} n'est pas une heure valide (entier entre 0 et 23)")


class EdtRecurring(models.Model):
    DAYS = (
        (0, "Lundi"),
        (1, "Mardi"),
        (2, "Mercredi"),
        (3, "Jeudi"),
        (4, "Vendredi"),
        (5, "Samedi"),
        (6, "Dimanche"),
    )
    CATEGORIES = (
        (Category.ADMIN, "de formalités administratives"),
        (Category.COURS, "de cours"),
        (Category.SPORT, "de sport"),
        (Category.TD, "de TD"),
        (Category.TP, "de TP"),
        (Category.PROJET, "de projet"),
        (Category.EXAMEN, "d’examen"),
        (Category.CLUB, "de club"),
    )

    start_hour = models.IntegerField(verbose_name="Heure de début", validators=[is_hour])
    end_hour = models.IntegerField(verbose_name="Heure de fin", validators=[is_hour])
    weekday = models.IntegerField(verbose_name="Jour de la semaine", choices=DAYS, default=0, blank=False)
    people = models.CharField(verbose_name="Responsable", max_length=250, blank=False)
    location = models.CharField(verbose_name="Lieu", max_length=25, blank=False)
    topic = models.CharField(verbose_name="Titre", max_length=250, blank=False)
    category = models.CharField(
        verbose_name="Catégorie",
        max_length=20,
        choices=CATEGORIES,
        default=Category.COURS,
        blank=False,
    )

    def __str__(self):
        return self.topic


class EdtClubs(models.Model):
    club = models.CharField(max_length=50)  # cn, pas de FK parce qu’on veut un LdapClub (discutable…)
    start = models.DateTimeField(verbose_name="Début")
    end = models.DateTimeField(
        verbose_name="Fin",
        help_text="Les événements peuvent "
        "s’étaler sur plusieurs jours. Si l’heure de fin d’un événement n’est pas "
        "déterminée (« tard dans la nuit »), utilisez 23:59:59 comme heure de fin "
        "(ou 00:00:00 le jour suivant).",
    )
    people = models.CharField(verbose_name="Respo", max_length=250)
    location = models.CharField(verbose_name="Lieu", max_length=25)
    topic = models.CharField(verbose_name="Sujet", max_length=250)
    descr = models.TextField(verbose_name="Description", max_length=250)
    public = models.BooleanField(verbose_name="Évènement public", default=False)

    def __str__(self):
        return self.topic

    class Meta:
        ordering = ["start"]
